Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IoT Core for LoRaWAN.

Actions, resources, and condition keys for AWS IoT Core for LoRaWAN - Service Authorization Reference

# Actions, resources, and condition keys for AWS IoT Core for LoRaWAN

AWS IoT Core for LoRaWAN (service prefix: `iotwireless` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS IoT Core for LoRaWAN
- Resource types defined by AWS IoT Core for LoRaWAN
- Condition keys for AWS IoT Core for LoRaWAN

## Actions defined by AWS IoT Core for LoRaWAN

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateAwsAccountWithPartnerAccount | Link partner accounts with Aws account. | Write |  |  |
AssociateWirelessDeviceWithThing | Associate the wireless device with AWS IoT thing for a given wirelessDeviceId. | Write | WirelessDevice* |  | iot:DescribeThing
thing* |  |
AssociateWirelessGatewayWithCertificate | Associate a WirelessGateway with the IoT Core Identity certificate. | Write | WirelessGateway* |  |
cert* |  |
AssociateWirelessGatewayWithThing | Associate the wireless gateway with AWS IoT thing for a given wirelessGatewayId. | Write | WirelessGateway* |  | iot:DescribeThing
thing* |  |
CreateDestination | Create a Destination resource. | Write | Destination* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDeviceProfile | Create a DeviceProfile resource. | Write | DeviceProfile* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateServiceProfile | Create a ServiceProfile resource. | Write | ServiceProfile* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWirelessDevice | Create a WirelessDevice resource with given Destination. | Write | Destination* |  |
WirelessDevice* |  |
CreateWirelessGateway | Create a WirelessGateway resource. | Write | WirelessGateway* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWirelessGatewayTask | Create a task for a given WirelessGateway. | Write | WirelessGateway* |  |
CreateWirelessGatewayTaskDefinition | Create a WirelessGateway task definition. | Write |  |  |
DeleteDestination | Delete a Destination. | Write | Destination* |  |
DeleteDeviceProfile | Delete a DeviceProfile. | Write | DeviceProfile* |  |
DeleteServiceProfile | Delete a ServiceProfile. | Write | ServiceProfile* |  |
DeleteWirelessDevice | Delete a WirelessDevice. | Write | WirelessDevice* |  |
DeleteWirelessGateway | Delete a WirelessGateway. | Write | WirelessGateway* |  |
DeleteWirelessGatewayTask | Delete task for a given WirelessGateway. | Write | WirelessGateway* |  |
DeleteWirelessGatewayTaskDefinition | Delete a WirelessGateway task definition. | Write |  |  |
DisassociateAwsAccountFromPartnerAccount | Disassociate an AWS account from a partner account. | Write |  |  |
DisassociateWirelessDeviceFromThing | Disassociate a wireless device from a AWS IoT thing. | Write | WirelessDevice* |  | iot:DescribeThing
thing* |  |
DisassociateWirelessGatewayFromCertificate | Disassociate a WirelessGateway from a IoT Core Identity certificate. | Write | WirelessGateway* |  |
cert* |  |
DisassociateWirelessGatewayFromThing | Disassociate a WirelessGateway from a IoT Core thing. | Write | WirelessGateway* |  | iot:DescribeThing
thing* |  |
GetDestination | Get the Destination | Read | Destination* |  |
GetDeviceProfile | Get the DeviceProfile | Read | DeviceProfile* |  |
GetPartnerAccount | Get the associated PartnerAccount | Read |  |  |
GetServiceEndpoint | Retrieve the customer account specific endpoint for CUPS protocol connection or LoRaWAN Network Server (LNS) protocol connection, and optionally server trust certificate in PEM format. | Read |  |  |
GetServiceProfile | Get the ServiceProfile | Read | ServiceProfile* |  |
GetWirelessDevice | Get the WirelessDevice | Read | WirelessDevice* |  |
GetWirelessDeviceStatistics | Get statistics info for a given WirelessDevice | Read | WirelessDevice* |  |
GetWirelessGateway | Get the WirelessGateway | Read | WirelessGateway* |  |
GetWirelessGatewayCertificate | Get the IoT Core Identity certificate id associated with the WirelessGateway. | Read | WirelessGateway* |  |
GetWirelessGatewayFirmwareInformation | Get Current firmware version and other information for the WirelessGateway | Read | WirelessGateway* |  |
GetWirelessGatewayStatistics | Get statistics info for a given WirelessGateway | Read | WirelessGateway* |  |
GetWirelessGatewayTask | Get the task for a given WirelessGateway | Read | WirelessGateway* |  |
GetWirelessGatewayTaskDefinition | Describe the given WirelessGateway task definition. | Read |  |  |
ListDestinations | List information of available Destinations based on the AWS account. | List |  |  |
ListDeviceProfiles | List information of available DeviceProfiles based on the AWS account. | List |  |  |
ListPartnerAccounts | Lists the available partner accounts. | List |  |  |
ListServiceProfiles | List information of available ServiceProfiles based on the AWS account. | List |  |  |
ListTagsForResource | Lists all tags for a given resource. | List | Destination |  |
DeviceProfile |  |
ServiceProfile |  |
WirelessGateway |  |
ListWirelessDevices | List information of available WirelessDevices based on the AWS account. | List |  |  |
ListWirelessGatewayTaskDefinitions | List information of available WirelessGateway task definitions based on the AWS account. | List |  |  |
ListWirelessGateways | List information of available WirelessGateways based on the AWS account. | List |  |  |
SendDataToWirelessDevice | Send the decrypted application data frame to the target device | Write | WirelessDevice* |  |
TagResource | Tag a given resource. | Tagging | Destination |  |
DeviceProfile |  |
ServiceProfile |  |
WirelessGateway |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
TestWirelessDevice | Simulate a provisioned device to send an uplink data with payload of 'Hello' | Write | WirelessDevice* |  |
UntagResource | Remove the given tags from the resource. | Tagging | Destination |  |
DeviceProfile |  |
ServiceProfile |  |
WirelessGateway |  |
| aws:TagKeys |
UpdateDestination | Update a Destination resource. | Write | Destination* |  |
UpdatePartnerAccount | Update a partner account. | Write |  |  |
UpdateWirelessDevice | Update a WirelessDevice resource. | Write | WirelessDevice* |  |
UpdateWirelessGateway | Update a WirelessGateway resource. | Write | WirelessGateway* |  |

## Resource types defined by AWS IoT Core for LoRaWAN

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
WirelessDevice | `arn:$ { Partition}:iotwireless:$ { Region}:$ { Account}:WirelessDevice/$ { WirelessDeviceId}` |
WirelessGateway | `arn:$ { Partition}:iotwireless:$ { Region}:$ { Account}:WirelessGateway/$ { WirelessGatewayId}` | aws:ResourceTag/${TagKey}
DeviceProfile | `arn:$ { Partition}:iotwireless:$ { Region}:$ { Account}:DeviceProfile/$ { DeviceProfileId}` | aws:ResourceTag/${TagKey}
ServiceProfile | `arn:$ { Partition}:iotwireless:$ { Region}:$ { Account}:ServiceProfile/$ { ServiceProfileId}` | aws:ResourceTag/${TagKey}
Destination | `arn:$ { Partition}:iotwireless:$ { Region}:$ { Account}:Destination/$ { DestinationName}` | aws:ResourceTag/${TagKey}
thing | `arn:$ { Partition}:iot:$ { Region}:$ { Account}:thing/$ { ThingName}` |
cert | `arn:$ { Partition}:iot:$ { Region}:$ { Account}:cert/$ { Certificate}` |

## Condition keys for AWS IoT Core for LoRaWAN

AWS IoT Core for LoRaWAN defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | A tag key that is present in the request that the user makes to IoT Wireless. | String
aws:ResourceTag/${TagKey} | The tag key component of a tag attached to an IoT Wireless resource. | String
aws:TagKeys | The list of all the tag key names associated with the resource in the request. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.